@@ -5,7 +5,6 @@ use feature 'say';
 use Test::LWP::UserAgent;
 
 my $useragent = Test::LWP::UserAgent->new;
-$useragent->network_fallback(1);
 $useragent->map_response(qr/example.com/, HTTP::Response->new(200));
 
 my $response = $useragent->get('http://example.com');
@@ -13,6 +12,6 @@ my $response = $useragent->get('http://example.com');
 say $response->code;
 
 $response = $useragent->get('http://google.com');
-# prints 200
+# prints 404
 say $response->code;
 
